@@ -20,7 +20,7 @@
 
 """CalDAV/CardDAV server."""
 
-import defusedxml.ElementTree  # noqa: F401: This does some monkey-patching on-load
+import defusedxml.ElementTree  # noqa: F401 This does some monkey-patching on-load
 
-__version__ = (0, 2, 12)
+__version__ = (0, 3, 3)
 version_string = ".".join(map(str, __version__))
